@@ -116,7 +116,15 @@ mcIgraph <- as(mcWeather, "igraph")
 
 
 ###################################################
-### code chunk number 15: exportImport2
+### code chunk number 15: importExportPlot
+###################################################
+library(igraph)
+importExportGraph<-graph.formula(dataframe++markovchain,markovchain-+igraph,markovchain++matrix,table-+markovchain)
+plot(importExportGraph,main="Import - Export from and to markovchain objects")
+
+
+###################################################
+### code chunk number 16: exportImport2
 ###################################################
 myMatr<-matrix(c(.1,.8,.1,.2,.6,.2,.3,.4,.3), byrow=TRUE, ncol=3)
 myMc<-as(myMatr, "markovchain")
@@ -124,7 +132,7 @@ myMc
 
 
 ###################################################
-### code chunk number 16: cchcMcList
+### code chunk number 17: cchcMcList
 ###################################################
 stateNames = c("H", "I", "D")
 Q0 <- new("markovchain", states = stateNames, 
@@ -139,26 +147,26 @@ print(mcCCRC)
 
 
 ###################################################
-### code chunk number 17: cchcMcList2
+### code chunk number 18: cchcMcList2
 ###################################################
 mcCCRC[[1]]
 dim(mcCCRC)
 
 
 ###################################################
-### code chunk number 18: conditionalDistr
+### code chunk number 19: conditionalDistr
 ###################################################
 conditionalDistribution(mcWeather, "sunny")
 
 
 ###################################################
-### code chunk number 19: steadyStates
+### code chunk number 20: steadyStates
 ###################################################
 steadyStates(mcWeather)
 
 
 ###################################################
-### code chunk number 20: gamblerRuin
+### code chunk number 21: gamblerRuin
 ###################################################
 gamblerRuinMarkovChain <- function(moneyMax, prob = 0.5) {
   require(matlab)
@@ -180,14 +188,14 @@ steadyStates(mcGR4)
 
 
 ###################################################
-### code chunk number 21: absorbingStates
+### code chunk number 22: absorbingStates
 ###################################################
 absorbingStates(mcGR4)
 absorbingStates(mcWeather)
 
 
 ###################################################
-### code chunk number 22: commclassKernel
+### code chunk number 23: commclassKernel
 ###################################################
 .commclassesKernel <- function(P){
   m <- ncol(P)
@@ -226,7 +234,7 @@ absorbingStates(mcWeather)
 
 
 ###################################################
-### code chunk number 23: renaldoMatrix1
+### code chunk number 24: renaldoMatrix1
 ###################################################
 P <- matlab::zeros(10)
 P[1, c(1, 3)] <- 1/2;
@@ -248,13 +256,13 @@ summary(probMc)
 
 
 ###################################################
-### code chunk number 24: transientStates
+### code chunk number 25: transientStates
 ###################################################
 transientStates(probMc)
 
 
 ###################################################
-### code chunk number 25: probMc2Canonic
+### code chunk number 26: probMc2Canonic
 ###################################################
 probMcCanonic <- canonicForm(probMc)
 probMc
@@ -262,14 +270,14 @@ probMcCanonic
 
 
 ###################################################
-### code chunk number 26: isAccessible
+### code chunk number 27: isAccessible
 ###################################################
 is.accessible(object = probMc, from = "a", to = "c")
 is.accessible(object = probMc, from = "g", to = "c")
 
 
 ###################################################
-### code chunk number 27: periodicity
+### code chunk number 28: periodicity
 ###################################################
 
 E <- matrix(0, nrow = 4, ncol = 4)
@@ -286,7 +294,7 @@ period(mcE)
 
 
 ###################################################
-### code chunk number 28: mathematica9Mc
+### code chunk number 29: mathematica9Mc
 ###################################################
 require(matlab)
 mathematicaMatr <- zeros(5)
@@ -301,19 +309,19 @@ mathematicaMc <- new("markovchain", transitionMatrix = mathematicaMatr,
 
 
 ###################################################
-### code chunk number 29: mathematica9McFig
+### code chunk number 30: mathematica9McFig
 ###################################################
 plot(mathematicaMc, layout = layout.fruchterman.reingold)
 
 
 ###################################################
-### code chunk number 30: mathematica9MC
+### code chunk number 31: mathematica9MC
 ###################################################
 summary(mathematicaMc)
 
 
 ###################################################
-### code chunk number 31: fpTime1 (eval = FALSE)
+### code chunk number 32: fpTime1 (eval = FALSE)
 ###################################################
 ## .firstpassageKernel <- function(P, i, n){
 ##   G <- P
@@ -328,7 +336,7 @@ summary(mathematicaMc)
 
 
 ###################################################
-### code chunk number 32: fpTime2
+### code chunk number 33: fpTime2
 ###################################################
 firstPassagePdF <- firstPassage(object = mcWeather, state = "sunny", 
                                 n = 10)
@@ -336,14 +344,14 @@ firstPassagePdF[3, 3]
 
 
 ###################################################
-### code chunk number 33: simulatingAMarkovChain
+### code chunk number 34: simulatingAMarkovChain
 ###################################################
 weathersOfDays <- rmarkovchain(n = 365, object = mcWeather, t0 = "sunny")
 weathersOfDays[1:30]
 
 
 ###################################################
-### code chunk number 34: simulatingAListOfMarkovChain
+### code chunk number 35: simulatingAListOfMarkovChain
 ###################################################
 patientStates <- rmarkovchain(n = 5, object = mcCCRC, t0 = "H", 
                               include.t0 = TRUE)
@@ -351,7 +359,7 @@ patientStates[1:10,]
 
 
 ###################################################
-### code chunk number 35: fitMcbyMLE
+### code chunk number 36: fitMcbyMLE
 ###################################################
 weatherFittedMLE <- markovchainFit(data = weathersOfDays, method = "mle",
                                  name = "Weather MLE")
@@ -359,7 +367,7 @@ weatherFittedMLE$estimate
 
 
 ###################################################
-### code chunk number 36: fitMcbyLAPLACE
+### code chunk number 37: fitMcbyLAPLACE
 ###################################################
 weatherFittedLAPLACE <- markovchainFit(data = weathersOfDays, 
                                     method = "laplace", laplacian = 0.01,
@@ -368,13 +376,13 @@ weatherFittedLAPLACE$estimate
 
 
 ###################################################
-### code chunk number 37: fitSequenceMatrix
+### code chunk number 38: fitSequenceMatrix
 ###################################################
 createSequenceMatrix(stringchar = weathersOfDays)
 
 
 ###################################################
-### code chunk number 38: fitMcbyBootStrap
+### code chunk number 39: fitMcbyBootStrap
 ###################################################
 weatherFittedBOOT <- markovchainFit(data = weathersOfDays, 
                                     method = "bootstrap", nboot = 100)
@@ -383,26 +391,34 @@ weatherFittedBOOT$standardError
 
 
 ###################################################
-### code chunk number 39: markovchainPredict
+### code chunk number 40: fitMclists
+###################################################
+data(holson)
+singleMc<-markovchainFit(data=holson[,2:12],name="holson")
+mcListFist<-markovchainListFit(data=holson[,2:12],name="holson")
+
+
+###################################################
+### code chunk number 41: markovchainPredict
 ###################################################
 predict(object = weatherFittedMLE$estimate, newdata = c("cloudy", "sunny"),
         n.ahead = 3)
 
 
 ###################################################
-### code chunk number 40: markovchainListPredict
+### code chunk number 42: markovchainListPredict
 ###################################################
 predict(mcCCRC, newdata = c("H", "H"), n.ahead = 5)
 
 
 ###################################################
-### code chunk number 41: markovchainListPredict2
+### code chunk number 43: markovchainListPredict2
 ###################################################
 predict(mcCCRC, newdata = c("H", "H"), n.ahead = 5, continue = TRUE)
 
 
 ###################################################
-### code chunk number 42: weatPred1
+### code chunk number 44: weatPred1
 ###################################################
 
 mcWP <- new("markovchain", states = c("rainy", "nice", "snowy"),
@@ -412,7 +428,7 @@ mcWP <- new("markovchain", states = c("rainy", "nice", "snowy"),
 
 
 ###################################################
-### code chunk number 43: weatPred2
+### code chunk number 45: weatPred2
 ###################################################
 W0 <- t(as.matrix(c(0, 1, 0)))
 W1 <- W0 * mcWP; W1
@@ -423,21 +439,21 @@ W3 <- W0 * (mcWP ^ 3); W3
 
 
 ###################################################
-### code chunk number 44: weatPred3
+### code chunk number 46: weatPred3
 ###################################################
 W7 <- W0 * (mcWP ^ 7)
 W7
 
 
 ###################################################
-### code chunk number 45: weatPred4
+### code chunk number 47: weatPred4
 ###################################################
 q <- steadyStates(mcWP)
 q
 
 
 ###################################################
-### code chunk number 46: weatPred5
+### code chunk number 48: weatPred5
 ###################################################
 R0 <- t(as.matrix(c(1, 0, 0)))
 R7 <- R0 * (mcWP ^ 7); R7
@@ -447,27 +463,27 @@ S7 <- S0 * (mcWP ^ 7); S7
 
 
 ###################################################
-### code chunk number 47: Alofi1
+### code chunk number 49: Alofi1
 ###################################################
 data("rain", package = "markovchain")
 table(rain$rain)
 
 
 ###################################################
-### code chunk number 48: Alofi2
+### code chunk number 50: Alofi2
 ###################################################
 mcAlofi <- markovchainFit(data = rain$rain, name = "Alofi MC")$estimate
 mcAlofi
 
 
 ###################################################
-### code chunk number 49: Alofi3
+### code chunk number 51: Alofi3
 ###################################################
 steadyStates(mcAlofi)
 
 
 ###################################################
-### code chunk number 50: ratings1
+### code chunk number 52: ratings1
 ###################################################
 
 rc <- c("AAA", "AA", "A", "BBB", "BB", "B", "CCC", "D")
@@ -483,7 +499,7 @@ creditMatrix <- matrix(c(90.81, 8.33, 0.68, 0.06, 0.08, 0.02, 0.01, 0.01,
 
 
 ###################################################
-### code chunk number 51: ratings2
+### code chunk number 53: ratings2
 ###################################################
 creditMc <- new("markovchain", transitionMatrix = creditMatrix, 
                 name = "S&P Matrix")
@@ -491,7 +507,7 @@ absorbingStates(creditMc)
 
 
 ###################################################
-### code chunk number 52: economicAnalysis1
+### code chunk number 54: economicAnalysis1
 ###################################################
 statesNames <- c("customer", "non customer")
 P <- zeros(2); P[1, 1] <- .9; P[1, 2] <- .1; P[2, 2] <- .95; P[2, 1] <- .05;
@@ -501,20 +517,20 @@ M <- zeros(2); M[1, 1] <- -20; M[1, 2] <- -30; M[2, 1] <- -40; M[2, 2] <- 0
 
 
 ###################################################
-### code chunk number 53: economicAnalysis2
+### code chunk number 55: economicAnalysis2
 ###################################################
 c1 <- 100 + conditionalDistribution(mcP, state = "customer") %*% M[1,]
 c2 <- 0 + conditionalDistribution(mcP, state = "non customer") %*% M[2,]
 
 
 ###################################################
-### code chunk number 54: economicAnalysis3
+### code chunk number 56: economicAnalysis3
 ###################################################
 as.numeric((c(1, 0)* mcP ^ 5) %*% (as.vector(c(c1, c2))))
 
 
 ###################################################
-### code chunk number 55: bonusMalus1
+### code chunk number 57: bonusMalus1
 ###################################################
 
 getBonusMalusMarkovChain <- function(lambda)
@@ -545,20 +561,20 @@ getBonusMalusMarkovChain <- function(lambda)
 
 
 ###################################################
-### code chunk number 56: bonusMalus2
+### code chunk number 58: bonusMalus2
 ###################################################
 bmMc <- getBonusMalusMarkovChain(0.05)
 as.numeric(steadyStates(bmMc))
 
 
 ###################################################
-### code chunk number 57: bonusMalus3
+### code chunk number 59: bonusMalus3
 ###################################################
 sum(as.numeric(steadyStates(bmMc)) * c(0.5, 0.7, 0.9, 1, 1.25))
 
 
 ###################################################
-### code chunk number 58: healthIns1
+### code chunk number 60: healthIns1
 ###################################################
 
 mcHI <- new("markovchain", states = c("active", "disable", "withdrawn", 
@@ -571,7 +587,7 @@ benefitVector <- as.matrix(c(0, 0, 500, 1000))
 
 
 ###################################################
-### code chunk number 59: healthIns2
+### code chunk number 61: healthIns2
 ###################################################
 T0 <- t(as.matrix(c(1, 0, 0, 0)))
 T1 <- T0 * mcHI
@@ -580,7 +596,7 @@ T3 <- T2 * mcHI
 
 
 ###################################################
-### code chunk number 60: healthIns3
+### code chunk number 62: healthIns3
 ###################################################
 PVFB <- T0 %*% benefitVector * 1.05 ^ -0 + 
   T1 %*% benefitVector * 1.05 ^ -1+
@@ -588,13 +604,13 @@ PVFB <- T0 %*% benefitVector * 1.05 ^ -0 +
 
 
 ###################################################
-### code chunk number 61: healthIns4
+### code chunk number 63: healthIns4
 ###################################################
 P <- PVFB / (T0[1] * 1.05 ^- 0 + T1[1] * 1.05 ^ -1 + T2[1] * 1.05 ^ -2)
 
 
 ###################################################
-### code chunk number 62: healthIns5
+### code chunk number 64: healthIns5
 ###################################################
 PVFB <- T2 %*% benefitVector * 1.05 ^ -1 + T3 %*% benefitVector * 1.05 ^ -2
 PVFP <- P*(T1[1] * 1.05 ^ -0 + T2[1] * 1.05 ^ -1)
@@ -603,7 +619,7 @@ V
 
 
 ###################################################
-### code chunk number 63: blandenEtAlii
+### code chunk number 65: blandenEtAlii
 ###################################################
 data("blanden")
 mobilityMc <- as(blanden, "markovchain")
@@ -611,26 +627,26 @@ mobilityMc
 
 
 ###################################################
-### code chunk number 64: blandenEtAlii2
+### code chunk number 66: blandenEtAlii2
 ###################################################
 plot(mobilityMc, main = '1970 mobility',vertex.label.cex = 2,
 		layout = layout.fruchterman.reingold)
 
 
 ###################################################
-### code chunk number 65: blandenEtAlii3
+### code chunk number 67: blandenEtAlii3
 ###################################################
 round(steadyStates(mobilityMc), 2)
 
 
 ###################################################
-### code chunk number 66: preproglucacon1
+### code chunk number 68: preproglucacon1
 ###################################################
 data("preproglucacon", package = "markovchain")
 
 
 ###################################################
-### code chunk number 67: preproglucacon2
+### code chunk number 69: preproglucacon2
 ###################################################
 mcProtein <- markovchainFit(preproglucacon$preproglucacon, 
                           name = "Preproglucacon MC")$estimate
@@ -638,7 +654,7 @@ mcProtein
 
 
 ###################################################
-### code chunk number 68: epid1
+### code chunk number 70: epid1
 ###################################################
 craigSendiMatr <- matrix(c(682, 33, 25,
               154, 64, 47,
@@ -653,14 +669,14 @@ mcM6
 
 
 ###################################################
-### code chunk number 69: epid2
+### code chunk number 71: epid2
 ###################################################
 eig <- eigen(mcM6@transitionMatrix)
 D <- diag(eig$values)
 
 
 ###################################################
-### code chunk number 70: epid3
+### code chunk number 72: epid3
 ###################################################
 V <- eig$vectors 
 V %*% D %*% solve(V)
